## Context
What was the situation or problem before this change?

## Change Summary
What changes were made?

## Rationale
Why was this approach taken?

## Impact
What parts of the system or workflows are affected?
